*********
Functions
*********

.. automodule:: networkx.classes.function
.. currentmodule:: networkx

Graph functions
---------------
.. autosummary::
   :toctree: generated/

   density
   info
   degree_histogram
   freeze
   is_frozen
   create_empty_copy


